/*
///////////////////////////////////////////////////////////////////////////////////
// Open SCAD Notes
% = background : # = debug : ! = root : * = disable

union() : intersection() : difference() : minkowski() :hull()
translate([X, Y, Z]) : rotate([X,Y,Z]) : scale([x, y, z])
linear_extrude(height = X, center = true, convexity = 10, twist = Y, slices = 20)

square ([X,Y],center = true) : cube([X, Y, Z], center=true)
circle(r = X) : cylinder(r1=X, r2=Y, h=Z, center=true, $fn=20) : sphere(2, $fn=100)
color("Red",0.7)

polygon(points=[[-50,0],[-50,50],[50,50],[50,0]], paths=[[0,1,2,3]]);
polyhedron(points=[[-50,0],[-50,50],[50,50],[50,0], triangles=[[1,0,3],[2,1,3]]);

// STL Import
translate([0, 0, 0])
import("OpenBeam.stl");

///////////////////////////////////////////////////////////////////////////////////
*/

include <metric_fastners.scad>;

// standard parameters
$fn=30;

// Increase this if your slicer or printer makes the holes too small.
extra_radius = 0.10;
extra_boolean = 0.15;

// Use M5 sized hardware
bolt = m5_major_radius*2;
washer_height = 1.0; // M% washers are generally 1.0mm  
bolt_boolean = bolt+extra_radius;

// Router Mount parameters
router_radius=64;
height=20;
width=88;
scale=1.0;
bolt_seperation=73/2;
rear_countersink=width/2-9;


// Nut channels
module nut_channel() {
	hull() {	
		for (h = [-1,1]) {
		translate([0, 0, 10*h]) rotate([0, 90, 0])
		 flat_nut_boolean(bolt);
		}
	}
}


//Router Mount
module mount() {
	difference() {
		union() {
			minkowski() {
				translate([0, 0, 0]) rotate([0, 0, 0])
				 cube([width-20, width-20, height], center=true);
			
				translate([0, 0, 0]) rotate([0, 0, 0])
				 cylinder(r=10, h=1, center=true);
			}

// notches
			translate([-width/2, 10, 0]) rotate([0, 0, 0])
			 cylinder(r=4.5, h=height+1, center=true,  $fn=4);	
			translate([-width/2, -10, 0]) rotate([0, 0, 0])
			 cylinder(r=4.5, h=height+1, center=true,  $fn=4);

		}
		
// central cutout
			translate([2, 0, 0]) rotate([0, 0, 0])
			 cylinder(r=router_radius/2, h=height*2, center=true, $fn=90);

//plane notches

			translate([-width/2-3.8, 10, 0]) rotate([0, 0, 0])
			 cube([4, width*2, height*2], center=true);	

// split
			translate([0, 0, 0]) rotate([0, 0, 0])
			 cube([20, width*2, height*2], center=true);

// bolts
#	union() {
		for (mx = [-1,1]) {
			translate([-rear_countersink, 10*mx, 0]) rotate([0, -90, 0])
			 cap_bolt_boolean(bolt_boolean, 20, 30);

			translate([width/2-8, bolt_seperation*mx, 0]) rotate([0, -90, 0])
			 cap_bolt_boolean(bolt_boolean, 70, 30);
			translate([-width/4, bolt_seperation*mx-10*mx, 0]) rotate([90, 0, 0])
			 nut_channel();
		}
	}
			
	}

// dimples for extra grip
		for (a = [30:60:360]) translate([2, 0, 0]) rotate([0, 0, a]) {
			translate([0, router_radius/2+1.2, 0]) rotate([90, 0, 0])
			 sphere(2, $fn=10);
		 }
}



//render
	translate([0, 0, 0]) rotate([0, 0, 0]) scale([scale, scale, scale])
	 mount();





